@@ -13,7 +13,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-## addtogroup pkg_py_laldetchar_idq
+## \addtogroup laldetchar_py_idq
 ## Synopsis
 # ~~~
 # from laldetchar.idq import auxmvc
@@ -35,7 +35,7 @@ __version__ = git_version.id
 __date__ = git_version.date
 
 
-## addtogroup pkg_py_laldetchar_idq_auxmvc
+## \addtogroup laldetchar_py_idq_auxmvc
 # @{
 
 # definitions of condor job and node classes for auxmvc algroithms.
@@ -305,7 +305,8 @@ class add_file_to_cache_job(auxmvc_analysis_job):
         """
     """
 
-        sections = ['add_file_to_cache']
+#        sections = ['add_file_to_cache']
+        sections = [] ### never actually used, only references "condor" section
         exec_name = 'add_file_to_cache'
         tag_base = 'add_file_to_cache'
         auxmvc_analysis_job.__init__(self, cp, sections, exec_name,
@@ -460,13 +461,12 @@ class forest_add_excluded_vars_job(auxmvc_analysis_job):
         """
     """
 
-        sections = ['forest_add_excluded_vars']
+#        sections = ['forest_add_excluded_vars']
+        sections = [] ### not used...
         exec_name = 'forest_add_excluded_vars'
         tag_base = 'forest_add_excluded_vars'
-        auxmvc_analysis_job.__init__(self, cp, sections, exec_name,
-                tag_base=tag_base)
-        self.add_opt('excluded-variables', cp.get('forest_evaluate', 'z'
-                     ))
+        auxmvc_analysis_job.__init__(self, cp, sections, exec_name, tag_base=tag_base)
+        self.add_opt('excluded-variables', cp.get('forest_evaluate', 'z'))
 
 
 class forest_add_excluded_vars_node(pipeline.CondorDAGNode):
