@@ -15,7 +15,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-## addtogroup pkg_py_laldetchar_idq
+## \addtogroup laldetchar_py_idq
 ## Synopsis
 # ~~~
 # from laldetchar.idq import ovl
@@ -39,7 +39,7 @@ __author__ = 'Reed Essick <reed.essick@ligo.org>'
 __version__ = git_version.id
 __date__ = git_version.date
 
-## addtogroup pkg_py_laldetchar_idq_ovl
+## \addtogroup laldetchar_py_idq_ovl
 # @{
 
 # Encapsulates all the key OVL scripts as functions
@@ -164,7 +164,7 @@ def rank_to_vsig(rank):
 def useP_to_rank(useP):
     """ conversion from useP to rank """
 
-    return 1. - math.exp(-useP / 0.5)
+    return 1. - math.exp(- useP / 0.5)
 
 
 def rank_to_useP(rank):
@@ -183,7 +183,7 @@ def __check_dirname(dir):
     return dir
 
 
-# =================================================
+#=================================================
 
 def __load_channels(auxdir, analysis_range=False):
     """ loads channels for OVL analysis 
@@ -215,7 +215,7 @@ def __load_channels(auxdir, analysis_range=False):
     return channels
 
 
-# =================================================
+#=================================================
 
 def load_trg(
     trgdir,
@@ -278,7 +278,7 @@ def load_trg(
     return (trg, seg)
 
 
-# =================================================
+#=================================================
 
 def round_robin_bin_to_segments(binNo, totBins, __params):
     """ defines segments for a round-robin analysis 
@@ -518,6 +518,154 @@ def write_params(__params, params_filename, params_dir=''):
 #
 # ===================================================================================================
 
+def redundancies(__params, output_dir="./", verbose=False, write_channels=False):
+    """
+    computes the intersection and overlap of vetosegments for each possible configuration. 
+    This should contain all information necessary to determine which channels are redundant.
+    """
+
+    output_dir = __check_dirname(output_dir)
+    if not os.path.exists(output_dir):
+        os.makedirs(output_dir)
+
+    # path to auxiliary channel KW triggers
+    auxdir = __params.auxdir
+
+    # path to gw channel KW triggers
+    gwdir = __params.gwdir
+
+    # load list of auxiliary channels
+    if vars(__params).has_key('channels'):
+        channels = event.loadlist(__params.channels)
+    else:
+        channels = __load_channels(auxdir,
+                                   analysis_range=__params.analysis_range)
+
+    # we need the same channels list as for recalculate.py so we can associate numbers with channels
+    for remove in __params.notused:
+        channels = [channel for channel in channels
+                    if channel.find(remove) == -1]
+
+    # create a channels file
+    if write_channels:
+        ch_file = open(output_dir + 'channels.txt', 'w')
+        for chan in channels:
+            print >> ch_file, chan
+        ch_file.close()
+
+    ### segments for this analysis range
+    gwseg = [__params.analysis_range]
+
+    # load (and clean) a list of segments for science runs
+    scisegs = dict()
+    if vars(__params).has_key('scisegs'):
+        for (i, ifo) in enumerate(__params.ifos):
+            segs = event.load(__params.scisegs[i])
+
+            # segwizard format
+            if len(segs) > 0 and len(segs[0]) > 2:
+                # assume that the biggest number will be the stop time of the first segment
+                index = segs[0].index(max(segs[0]))
+                segs = [seg[index - 1:index + 1] for seg in segs]
+            gwseg = event.andsegments([gwseg, segs])  # intersect segs with analysis range
+    
+    # load (and clean) a list of veto segements
+    vetosegs = dict()
+    if vars(__params).has_key('vetosegs'):
+        for (i, ifo) in enumerate(__params.ifos):
+            segs = event.load(params.vetosegs[i])
+            if len(segs) > 0 and len(segs[0]) > 2:
+                index = (segs[0], index(max(segs[0])))
+                segs = [seg[index - 1:index + 1] for seg in segs]
+            gwseg = event.removesegments( gwseg, segs )
+
+    livetime = event.livetime(gwseg) ### total amount of time in the analysis
+
+    # create a list of all veto triggers to avoid loading multiple times
+    allvtrg = [0 for i in channels]
+    allvseg = [[[0 for i in __params.thresholds] for j in __params.windows] for k in channels]
+
+    nthr = len(__params.thresholds)
+    nwin = len(__params.windows)
+    nconfig = nthr*nwin
+
+    ### iterate over channels, creating segments and comparing them
+    filename = "redundancies.txt"
+    f = open(output_dir + filename, "w")
+
+    print >>f, livetime
+    if verbose:
+        print livetime
+
+    s = ""
+    for chan in channels:
+        for vwin in __params.windows:
+            for vthr in __params.thresholds:
+                s += " (%s,%f,%f)"%(chan, vwin, vthr)
+    print >>f, s
+    if verbose:
+        print s
+
+    event.col = event.col_veto
+    for indA, chanA in enumerate(channels):
+        if allvtrg[indA] == 0: ### load chanA triggers
+            allvtrg[indA], _ = load_trg( auxdir, __params.analysis_range, [chanA], __params.thresholds[0], trgtype=__params.trgtype, loadtype='veto', suffix=__params.suffix)
+  
+        for indvwinA, vwinA in enumerate(__params.windows):
+            for indvthrA, vthrA in enumerate(__params.thresholds):
+
+                if allvseg[indA][indvwinA][indvthrA] == 0:
+                    vetosegA = event.vetosegs(allvtrg[indA], vwinA, vthrA) ### generate chanA segments
+                    vetosegA = event.andsegments([vetosegA, gwseg])              
+                    livetimeA = event.livetime(vetosegA)
+                    allvseg[indA][indvwinA][indvthrA] = (vetosegA, livetimeA)
+                else:
+                    vetosegA, livetimeA = allvseg[indA][indvwinA][indvthrA]
+
+                s = ""
+
+                for indB, chanB in enumerate(channels[indA+1:]):
+                    indB += indA+1
+                    if allvtrg[indB] == 0: ### load chanB triggers
+                        allvtrg[indB], _ = load_trg( auxdir, __params.analysis_range, [chanB], __params.thresholds[0], trgtype=__params.trgtype, loadtype='veto', suffix=__params.suffix)
+                    for indvwinB, vwinB in enumerate(__params.windows):
+                        for indvthrB, vthrB in enumerate(__params.thresholds):
+
+                            if allvseg[indB][indvwinB][indvthrB] == 0:
+                                vetosegB = event.vetosegs(allvtrg[indB], vwinB, vthrB) ### generate chanB segments
+                                vetosegB = event.andsegments([vetosegB, gwseg])
+                                livetimeB = event.livetime(vetosegB)
+                                allvseg[indB][indvwinB][indvthrB] = (vetosegB, livetimeB)
+                            else:
+                                vetosegB, livetimeB = allvseg[indB][indvwinB][indvthrB]
+
+                            ### compare segments
+                            i = event.livetime( event.andsegments([vetosegA, vetosegB]) )
+                            u = event.livetime( event.andsegments([vetosegA, vetosegB]) )
+
+                            if livetimeA and livetimeB:
+                                stat1 = i*livetime/(livetimeA*livetimeB)
+                            else:
+                                stat1 = 1
+                            if u:
+                                stat2 = i/u
+                            else:
+                                stat2 = 0
+
+                            s += "(%9.3f,%9.3f,%9.3f,%9.3f,%5.1f,%1.4f) "%(livetimeA, livetimeB, i, u, stat1, stat2)
+
+                print >> f, s
+                if verbose:
+                    print s
+
+                allvseg[indA][indvwinA][indvthrA] = 0 ### forget about segments for this config
+                            
+        allvtrg[indA] = 0 ### forget about triggers we don't need anymore
+
+    return filename
+
+#=================================================
+
 def recalculate(
     run,
     incremental,
@@ -880,7 +1028,7 @@ def recalculate(
             livetime = event.livetime(gwseg)
             if ngwtrg <= 0 or livetime <= 0:  # stop if there are no more gwtrg
                 if verbose:
-                    print 'ngwtrg = ' + strg(ngwtrg)
+                    print 'ngwtrg = ' + str(ngwtrg)
                     print 'livetime = ' + str(livetime)
                     print 'gwseg = ' + str(gwseg)
                     print 'line = ' + str(line)
@@ -1557,11 +1705,11 @@ def stats_to_ROC(
     if cleans_statsfilename:
         print >> f, '# line 2 : total number of clean samples'
         print >> f, \
-            '# line 3 : rank(eff/dt) cumulative_number_of_cleans_removed cumulative_number_of_GWtrg_removed'
+            '# line 3 : rank(%s) cumulative_number_of_cleans_removed cumulative_number_of_GWtrg_removed'%__params.metric
     else:
         print >> f, '# line 2 : total amount of livetime'
         print >> f, \
-            '# line 3 : rank(eff/dt) cumulative_deadtime cumulative_number_of_GWtrg_removed'
+            '# line 3 : rank(%s) cumulative_deadtime cumulative_number_of_GWtrg_removed'%__params.metric
 
     print >> f, stats[0][sD['#gwtrg']]  # total number of gwtrg
     if cleans_statsfilename:
@@ -1582,7 +1730,12 @@ def stats_to_ROC(
             c_dsec += line[sD['dsec']]  # the number of seconds removed
 
         if rank_statsfilename and __params:
-            rank = effbydt_to_rank(rank_stats[index][sD['eff/dt']])
+            if __params.metric == "eff/dt":
+                rank = effbydt_to_rank(rank_stats[index][sD['eff/dt']])
+            elif __params.metric == "vsig":
+                rank = vsig_to_rank(rank_stats[index][sD['vsig']]) 
+            elif __params.metric == "useP":
+                rank = useP_to_rank(rank_stats[index][sD['useP']])
         else:
             rank = 'na'
 
@@ -2124,7 +2277,58 @@ def train(
 
     return vetolists
 
+###
+def convergent_train(__params, num_runs=5, output_dir="./", verbose=False, write_channels=False):
+    """
+    trains OVL on a specified data set
+    increments incremental to keep pace with num_runs and auto-terminates iteration only when incremental==num_configs_in_list
+    once we run out of configs to keep in the list, we iterate "num_runs" more times to shake out any loose ends...
+        ==> We're still susceptible to Markovian cycles!
+    """
 
+    # set up output directory
+    output_dir = __check_dirname(output_dir)
+    OVL_dir = output_dir + 'ovl/'
+    if not os.path.exists(OVL_dir):
+        os.makedirs(OVL_dir)
+
+    # write params file into the directory
+    write_params(__params, 'params.txt', params_dir=OVL_dir)
+
+    # train OVL
+    ### initial run (everything is independent)
+    run = 0
+    while True:
+        statsfiles = recalculate( run, run, __params, source_dir=OVL_dir, output_dir=OVL_dir, eval=False, verbose=verbose, write_channels=False)[0]
+        run += 1
+
+        ### see how many surviving configurations there are
+        for statsfile in statsfiles:
+            nconfigs = len([line for line in open("%s/%s"%(OVL_dir, statsfile), "r").readlines() if line[0] != "#"])
+            if nconfigs > run: ### there are configs that are not applied hierarchically
+                break
+        else: ### only reached if all configs were applied hierarchically for all statsfiles
+            break
+
+    incremental = run-1
+
+    for run in xrange(run, run+num_runs):
+        recalculate( run, incremental, __params, source_dir=OVL_dir, output_dir=OVL_dir, eval=False, verbose=verbose, write_channels=False)
+    run += 1
+
+    # we only write the channel list on the last iteration
+    recalculate( run, incremental, __params, source_dir=OVL_dir, output_dir=OVL_dir, track=True, eval=True, verbose=verbose, write_channels=write_channels)
+
+    # generate vetolist
+    vetolists = vetolist_eval(run, __params, output_dir=OVL_dir, source_dir=OVL_dir, verbose=verbose)
+
+    # generate standard ROC file
+    for v in vetolists:
+        v = v.split('/')[-1]
+        roc_filename = vetolist_to_ROC(v, source_dir=OVL_dir,
+                output_dir=OVL_dir, metric=__params.metric)
+
+    return vetolists
 
 # ===================================================================================================
 #
@@ -2176,7 +2380,7 @@ def _gammln(xx):
 def _gser(
     a,
     x,
-    itmax=700,
+    itmax=10000,
     eps=3.e-7,
     ):
     """Series approx'n to the incomplete gamma function."""
@@ -2197,7 +2401,7 @@ def _gser(
         if abs(delta) < abs(sum) * eps:
             return (sum * math.exp(-x + a * math.log(x) - gln), gln)
         n = n + 1
-    raise max_iters, str((abs(delta), abs(sum) * eps))
+    raise StandardError, "%s_%s"%(max_iters, str((abs(delta), abs(sum) * eps)))
 
 
 # ========================
@@ -2205,7 +2409,7 @@ def _gser(
 def _gserln(
     a,
     x,
-    itmax=700,
+    itmax=10000,
     eps=3.e-7,
     ):
     """Series approx'n to the incomplete gamma function."""
@@ -2226,7 +2430,7 @@ def _gserln(
         if abs(delta) < abs(sum) * eps:
             return (math.log(sum) + -x + a * math.log(x) - gln, gln)
         n = n + 1
-    raise max_iters, str((abs(delta), abs(sum) * eps))
+    raise StandardError, "%s_%s"%(max_iters, str((abs(delta), abs(sum) * eps)))
 
 
 # ========================
@@ -2234,7 +2438,7 @@ def _gserln(
 def _gcf(
     a,
     x,
-    itmax=200,
+    itmax=1000,
     eps=3.e-7,
     ):
     """Continued fraction approx'n of the incomplete gamma function."""
@@ -2262,7 +2466,7 @@ def _gcf(
                 return (g * math.exp(-x + a * math.log(x) - gln), gln)
             gold = g
         n = n + 1
-    raise max_iters, str(abs((g - gold) / g))
+    raise StandardError, "%s_%s"%(max_iters, str((abs(delta), abs(sum) * eps)))
 
 
 # ========================
@@ -2270,7 +2474,7 @@ def _gcf(
 def _gcfln(
     a,
     x,
-    itmax=200,
+    itmax=1000,
     eps=3.e-7,
     ):
     """Continued fraction approx'n of the incomplete gamma function."""
@@ -2298,7 +2502,7 @@ def _gcfln(
                 return (math.log(g) + -x + a * math.log(x) - gln, gln)
             gold = g
         n = n + 1
-    raise max_iters, str(abs((g - gold) / g))
+    raise StandardError, "%s_%s"%(max_iters, str((abs(delta), abs(sum) * eps)))
 
 
 # ========================
